Capsules
========

A capsule is a single file with a ``.cap`` file extension. It contains the
code, metadata, model files, and any other files the capsule needs to operate.
See the `Introduction to Capsules`_ section in the User Manual for more
information.

API Methods
-----------

.. automethod:: brainframe.api.BrainFrameAPI.get_plugin

.. automethod:: brainframe.api.BrainFrameAPI.get_plugins

.. automethod:: brainframe.api.BrainFrameAPI.get_plugin_option_vals

.. automethod:: brainframe.api.BrainFrameAPI.set_plugin_option_vals

.. automethod:: brainframe.api.BrainFrameAPI.patch_plugin_option_vals

.. automethod:: brainframe.api.BrainFrameAPI.is_plugin_active

.. automethod:: brainframe.api.BrainFrameAPI.set_plugin_active

Data Structures
---------------

.. automodule:: brainframe.api.bf_codecs.plugin_codecs
   :members:

.. _`Introduction to Capsules`:
   https://aotu.ai/docs/capsule_development/introduction/
